# -*- coding: utf-8 -*-

from .pycon.pycon_crawler import PyConCrawler
from .python.python_crawler import PythonCrawler
from .pydata.pydata_crawler import PyDataCrawler
from .confs_tech.confs_tech_crawler import ConfsTechCrawler
from .italy.italy_crawler import ItalyCrawler
from .papercall.papercall_crawler import PapercallCrawler
